@@ -1,17 +1,18 @@
 package cli
 
 import (
-	"fmt"
 	"os"
 	"strings"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/build"
 	"github.com/spf13/cobra"
 )
 
 var (
-	configFlag     string
-	displayVersion bool
+	configFlag string
+	shellName  string
+	silent     bool
+	// Deprecated flags, should be kept to avoid breaking CLI integration.
+	initialize bool
 )
 
 var RootCmd = &cobra.Command{
@@ -26,10 +27,7 @@ on getting started, have a look at the docs at https://ohmyposh.dev`,
 			runInit(strings.ToLower(shellName))
 			return
 		}
-		if displayVersion {
-			fmt.Println(build.Version)
-			return
-		}
+
 		_ = cmd.Help()
 	},
 }
@@ -41,21 +39,14 @@ func Execute() {
 	}
 }
 
-// Backwards compatibility
-var (
-	shellName  string
-	initialize bool
-)
-
 func init() {
 	RootCmd.PersistentFlags().StringVarP(&configFlag, "config", "c", "", "config file path")
-	RootCmd.Flags().BoolVar(&displayVersion, "version", false, "version")
 
 	// Deprecated flags, should be kept to avoid breaking CLI integration.
 	RootCmd.Flags().BoolVarP(&initialize, "init", "i", false, "init")
 	RootCmd.Flags().StringVarP(&shellName, "shell", "s", "", "shell")
 
 	// Hide flags that are deprecated or for internal use only.
-	_ = RootCmd.Flags().MarkHidden("init")
-	_ = RootCmd.Flags().MarkHidden("shell")
+	RootCmd.PersistentFlags().BoolVar(&silent, "silent", false, "do not print anything")
+	_ = RootCmd.Flags().MarkHidden("silent")
 }
