@@ -119,10 +119,6 @@ func (segment *Segment) Execute(env runtime.Environment) {
 		return
 	}
 
-	if len(segment.Templates) != 0 {
-		segment.Template = segment.Templates.Resolve(segment.writer, "", segment.TemplatesLogic)
-	}
-
 	if segment.writer.Enabled() {
 		segment.Enabled = true
 		env.TemplateCache().AddSegmentData(segment.Name(), segment.writer)
@@ -142,8 +138,9 @@ func (segment *Segment) Render() {
 		return
 	}
 
-	segment.writer.SetText(text)
+	segment.SetText(text)
 	segment.setCache()
+	segment.env.TemplateCache().AddSegmentData(segment.Name(), segment.writer)
 }
 
 func (segment *Segment) Text() string {
@@ -277,6 +274,11 @@ func (segment *Segment) folderKey() string {
 }
 
 func (segment *Segment) string() string {
+	result := segment.Templates.Resolve(segment.writer, "", segment.TemplatesLogic)
+	if len(result) != 0 {
+		return result
+	}
+
 	if len(segment.Template) == 0 {
 		segment.Template = segment.writer.Template()
 	}
@@ -328,6 +330,10 @@ func (segment *Segment) evaluateNeeds() {
 		value += strings.Join(segment.BackgroundTemplates, "")
 	}
 
+	if len(segment.Templates) != 0 {
+		value += strings.Join(segment.Templates, "")
+	}
+
 	if !strings.Contains(value, ".Segments.") {
 		return
 	}
