@@ -5,9 +5,6 @@ import (
 	"errors"
 	"path/filepath"
 	"strings"
-
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
-	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 )
 
 const (
@@ -15,8 +12,7 @@ const (
 )
 
 type Firebase struct {
-	props properties.Properties
-	env   runtime.Environment
+	base
 
 	Project string
 }
@@ -29,11 +25,6 @@ func (f *Firebase) Template() string {
 	return " {{ .Project}} "
 }
 
-func (f *Firebase) Init(props properties.Properties, env runtime.Environment) {
-	f.props = props
-	f.env = env
-}
-
 func (f *Firebase) Enabled() bool {
 	cfgDir := filepath.Join(f.env.Home(), ".config", "configstore")
 	configFile, err := f.getActiveConfig(cfgDir)
