@@ -16,13 +16,12 @@ import (
 )
 
 type Commit struct {
-	// git log -1 --pretty="format:%an%n%ae%n%cn%n%ce%n%at%n%s"
+	Timestamp time.Time
 	Author    *User
 	Committer *User
-	Subject   string
-	Timestamp time.Time
-	Sha       string
 	Refs      *Refs
+	Subject   string
+	Sha       string
 }
 
 type Refs struct {
@@ -129,37 +128,33 @@ const (
 )
 
 type Git struct {
-	scm
-
+	User           *User
 	Working        *GitStatus
 	Staging        *GitStatus
-	Ahead          int
-	Behind         int
-	HEAD           string
+	commit         *Commit
+	UpstreamURL    string
+	UpstreamIcon   string
 	Ref            string
 	Hash           string
 	ShortHash      string
 	BranchStatus   string
 	Upstream       string
-	UpstreamIcon   string
-	UpstreamURL    string
+	HEAD           string
 	RawUpstreamURL string
-	UpstreamGone   bool
-	IsWorkTree     bool
-	IsBare         bool
-	User           *User
-	Detached       bool
-	Merge          bool
-	Rebase         bool
-	CherryPick     bool
-	Revert         bool
-
-	// needed for posh-git support
-	poshgit       bool
+	scm
+	Ahead         int
 	stashCount    int
 	worktreeCount int
-
-	commit *Commit
+	Behind        int
+	IsWorkTree    bool
+	Merge         bool
+	Rebase        bool
+	CherryPick    bool
+	Revert        bool
+	poshgit       bool
+	Detached      bool
+	IsBare        bool
+	UpstreamGone  bool
 }
 
 func (g *Git) Template() string {
@@ -167,6 +162,7 @@ func (g *Git) Template() string {
 }
 
 func (g *Git) Enabled() bool {
+	// g.command = GITCOMMAND
 	g.User = &User{}
 
 	if !g.shouldDisplay() {
@@ -197,6 +193,7 @@ func (g *Git) Enabled() bool {
 	if g.shouldIgnoreStatus() {
 		displayStatus = false
 	}
+
 	if displayStatus {
 		g.setGitStatus()
 		g.setGitHEADContext()
@@ -204,21 +201,34 @@ func (g *Git) Enabled() bool {
 	} else {
 		g.setPrettyHEADName()
 	}
+
 	if g.props.GetBool(FetchUpstreamIcon, false) {
 		g.UpstreamIcon = g.getUpstreamIcon()
 	}
+
 	return true
 }
 
+func (g *Git) CacheKey() (string, bool) {
+	dir, err := g.env.HasParentFilePath(".git", true)
+	if err != nil {
+		return "", false
+	}
+
+	return dir.Path, true
+}
+
 func (g *Git) Commit() *Commit {
 	if g.commit != nil {
 		return g.commit
 	}
+
 	g.commit = &Commit{
 		Author:    &User{},
 		Committer: &User{},
 		Refs:      &Refs{},
 	}
+
 	commitBody := g.getGitCommandOutput("log", "-1", "--pretty=format:an:%an%nae:%ae%ncn:%cn%nce:%ce%nat:%at%nsu:%s%nha:%H%nrf:%D", "--decorate=full")
 	splitted := strings.Split(strings.TrimSpace(commitBody), "\n")
 	for _, line := range splitted {
@@ -273,10 +283,12 @@ func (g *Git) StashCount() int {
 	if g.poshgit || g.stashCount != 0 {
 		return g.stashCount
 	}
+
 	stashContent := g.FileContents(g.rootDir, "logs/refs/stash")
 	if stashContent == "" {
 		return 0
 	}
+
 	lines := strings.Split(stashContent, "\n")
 	g.stashCount = len(lines)
 	return g.stashCount
@@ -294,9 +306,11 @@ func (g *Git) Kraken() string {
 		}
 		g.RawUpstreamURL = g.getRemoteURL()
 	}
+
 	if len(g.Hash) == 0 {
 		g.Hash = g.getGitCommandOutput("rev-parse", "HEAD")
 	}
+
 	return fmt.Sprintf("gitkraken://repolink/%s/commit/%s?url=%s", root, g.Hash, url2.QueryEscape(g.RawUpstreamURL))
 }
 
@@ -324,10 +338,6 @@ func (g *Git) shouldDisplay() bool {
 		return false
 	}
 
-	if g.shouldIgnoreRootRepository(gitdir.ParentFolder) {
-		return false
-	}
-
 	g.setDir(gitdir.Path)
 
 	if !gitdir.IsDir {
