@@ -44,17 +44,15 @@ const (
 )
 
 type Sapling struct {
-	scm
-
+	Working     *SaplingStatus
 	ShortHash   string
 	Hash        string
 	When        string
 	Author      string
 	Bookmark    string
 	Description string
-	New         bool
-
-	Working *SaplingStatus
+	scm
+	New bool
 }
 
 func (sl *Sapling) Template() string {
@@ -72,28 +70,36 @@ func (sl *Sapling) Enabled() bool {
 }
 
 func (sl *Sapling) shouldDisplay() bool {
+	sl.command = SAPLINGCOMMAND
+
 	if !sl.hasCommand(SAPLINGCOMMAND) {
 		return false
 	}
 
-	slDir, err := sl.env.HasParentFilePath(".sl")
+	slDir, err := sl.env.HasParentFilePath(".sl", false)
 	if err != nil {
 		return false
 	}
 
-	if sl.shouldIgnoreRootRepository(slDir.ParentFolder) {
-		return false
-	}
-
 	sl.workingDir = slDir.Path
 	sl.rootDir = slDir.Path
 	// convert the worktree file path to a windows one when in a WSL shared folder
 	sl.realDir = strings.TrimSuffix(sl.convertToWindowsPath(slDir.Path), "/.sl")
 	sl.RepoName = runtime.Base(sl.env, sl.convertToLinuxPath(sl.realDir))
 	sl.setDir(slDir.Path)
+
 	return true
 }
 
+func (sl *Sapling) CacheKey() (string, bool) {
+	dir, err := sl.env.HasParentFilePath(".sl", true)
+	if err != nil {
+		return "", false
+	}
+
+	return dir.Path, true
+}
+
 func (sl *Sapling) setDir(dir string) {
 	dir = runtime.ReplaceHomeDirPrefixWithTilde(sl.env, dir) // align with template PWD
 	if sl.env.GOOS() == runtime.WINDOWS {
