@@ -4,7 +4,6 @@ import (
 	"testing"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/cache"
-	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
 
 	"github.com/stretchr/testify/assert"
@@ -25,16 +24,16 @@ func TestGlob(t *testing.T) {
 
 	env := &mock.Environment{}
 	env.On("DebugF", testify_.Anything, testify_.Anything).Return(nil)
-	env.On("TemplateCache").Return(&cache.Template{
-		Env: make(map[string]string),
-	})
-	env.On("Flags").Return(&runtime.Flags{})
+	env.On("TemplateCache").Return(&cache.Template{})
+	env.On("Shell").Return("foo")
+	env.On("Trace", testify_.Anything, testify_.Anything).Return(nil)
+
+	Init(env)
 
 	for _, tc := range cases {
 		tmpl := &Text{
 			Template: tc.Template,
 			Context:  nil,
-			Env:      env,
 		}
 
 		text, err := tmpl.Render()
